#
# spec file for package erdtree
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           erdtree
Version:        3.1.2~0
Release:        2.3
Summary:        A multi-threaded file-tree visualizer and disk usage analyzer
License:        MIT
Group:          Productivity/File utilities
URL:            https://github.com/solidiquis/erdtree
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging

%description
A multi-threaded file-tree visualizer and disk usage analyzer.

%prep
%autosetup -a1
mkdir -p .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%{_bindir}/erd

%changelog
* Wed Mar 20 2024 Michael Vetter <mvetter@suse.com>
- Filter dependencies for vendor tarball
* Sun Jul  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.1.2:
  * Fix loading .erdtree.toml on Windows #218
  * Fixed race to print #220
* Sun Jul  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.1.1:
  * Fix deadlock issue #214
* Sun Jul  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.1:
  * Multiple configs with .erdtree.toml
  * Increased performance with --suppress-size
  * -x, --one-file-system
  * Support for NO_COLOR
  * Inverted flat layout
  * Aliases: atime, ctime, and mtime
  * ctrlc handler to restore cursor if progress indicator is enabled
  * .erdtreerc will be deprecated by v3.3 in favor of .erdtree.toml.
    Please be sure to migrate by then and be sure to visit the Changelog
    for further details about .erdtree.toml and the new release.
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.0.2:
  * Fix segmentation fault when invalid group or user #193
  * Update deprecated Nerd symbols #192
  * Change CJK and emoji block icons #194
* Mon May 29 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.0.1:
  * Fixed issue where empty directories were automatically being pruned
    despite not opting into --prune.
  * Fixed issue where searching via globs or regex doesn't work when
    user has a config file.
  * Added exit codes to erdtree.
  * Progress indicator now acquires a lock to stdout reduce likelihood
    of printing the progress-text being a bottleneck.
  * Some code-cleanup.
* Sun May 28 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.0.0:
  * Added support for owners and groups for the ls -l-like -l,
  - -long view (Unix).
  * Edited the default fields shown in the -l, --long view to
    reduce clutter; made the removed fields optional (Unix).
  * Added support for various other disk usage metrics:
    blocks (Unix), word-count, and line-count.
  * Added a progress indicator.
  * Added comparators for sorting by time accessed, created, and modified.
  * Added support for specifying a custom time format
* Sat Apr 29 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.0.0:
  * Regular expressions #130
  * Unix permissions #132
  * Force color #135
  * Show hardlinks without double counting file size #136
  * Regular expressions and globbing with file-type #137
  * Truncate output #138
  * Inverted tree layout #139
  * Binary has been renamed from et to erd in order to
    address the following issue regarding name collisions with
    other programs: #23
* Tue Apr 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.8.1:
  * Fix some typos #110
  * Add clap requires to flags that depent on --report #111
  * Refactor tests: move --no-config to mod::run_cmd #112
  * Prevent panic when --prune is used with --glob which results
    in empty match set #116
  * Add ability to take glob patterns from stdin #114
  * Refactor/node and support hard link detection on Windows #118
  * Support colorless output when redirecting/piping stdout;
    also provide --no-color option #120
  * Remove ansi escapes for default icon #122
* Fri Mar 31 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.7.1:
  * Fix issue where not-existent directory as cli arg causes
    infinite loop #107
* Thu Mar 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.7.0:
  * Fix windows can not recognize the tag version when publishing #91
  * Fix the problem that test actions cannot upload windows binary files,
    add the function of custom form to set tag version. #94
  * Reduce default thread count #99
  * option for plain text disk usage reporting #102
  * Prune bug #103
  * dirs-only #104
  * Feature/file count #105
* Mon Mar 20 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.6.0:
  * Add NetBSD instructions #77
  * Add repology badge #76
  * Fix issue where level wasn't being read from config #78
  * Add scoop manifest #80
  * Default to num logical cpus rather than 4 threads #81
  * Add support for generating shell completions #82
  * Fix miscoloration of directories that have extension #83
  * [Optimization] - Upgraded heap-based tree data structure to an index-tree #86
  * Replace tempdir crate with tempfile crate #87
  * Fix issue where ansi escapes were being printed raw on windows #90
* Wed Mar 15 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.5.2:
  * Fix stray print
* Wed Mar 15 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.5.0:
  * Added --size-left to print disk usage to the left of the tree #611
  * Added more paths the erdtree config could be placed at #702
  * Fixed issue where --dirs-first wouldn't work unless -s, --sort was specified #67
  * Fixed isse where arguments from the erdtree config were being completely disregarded #74
* Mon Mar 13 2023 Michael Vetter <mvetter@suse.com>
- Initial package of erdtree 1.4.1 for openSUSE
